*********
Changelog
*********

0.1.3 (2019-01-24)
==================

* Pinned specific package versions
* Updated to use the last version of wsproto (0.13)
* The Trinket application now inherits from dict to allow arbitrary storage
* Decoupled the TCP serving/socket creation from the actual application

0.1.2 (2019-01-18)
==================

* Updated distribution files

0.1.1 (2019-01-18)
==================

* Added tests and testing utilities
* Fixed missing imports

0.1 (2019-01-17)
================

* Initial release
